.. _swh-export:

.. include:: README.rst

:ref:`The Software Heritage Graph Dataset <swh-graph-dataset>`
    the entire graph of Software Heritage in a fully-deduplicated Merkle DAG
    representation.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :titlesonly:

   graph/index
   export
   generate_subdataset

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
